class Admin::ProjectsController < OrbitMemberController
  include Admin::PersonalProjectsHelper
  layout "member_plugin"

  before_action :set_project, only: [:show, :edit , :update, :destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]
  def merge_process
    params['project_id'].each do |project_id|
        project_ids = project_id.split('/')
        projects = Project.find(project_ids)
        member_ids = projects.collect(&:member_profile_id).uniq
        projects.each_with_index do |project,index1|
            if index1== 0
                project.member_profile_id = member_ids
                project.save!
            else
                project.delete
            end
        end
    end
    redirect_to :action=> 'index'
  end
  def merge
    @projects=Project.order_by(:year=>'desc').map{|value| value}.group_by{|v| [v[:project_title],v[:unit]]}
    @projects.each do |key,value|
      if value.length<=1
        @projects.delete key
      end
    end
    if params['mode']!='simple'
      @projects.each do |key,value|
        @projects[key] = value.group_by{|v| [get_year(v),v.participator.to_s,get_project_type(v),get_period(v)]}
        @projects[key].each do |key1,value1|
          if value1.length<=1
            @projects[key].delete key1
          end
        end
        if @projects[key].length==0
            @projects.delete key
        end
      end
      
    end
  end

  def index
    @projects = Project.order_by(:period_start_date=>'desc',:year=>'desc').page(params[:page]).per(10)
  end

  def new
    @member = Array(MemberProfile.find_by(:uid=>params['uid'])) rescue nil
    @project = Project.new
    if params[:desktop]
      render :layout => false
    end
  end

  def analysis
  end

  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])
    
    render :layout => false
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="projects.xlsx"'
      }
    end
  end

  def create

    if !project_params['member_profile_id'].blank?

      @member = MemberProfile.find(project_params['member_profile_id']) rescue nil
      @project = Project.new(project_params)
      @project.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      #params[:author_members].each do |author_member|

        project_params['member_profile_id'] = params[:author_members]
        @project = Project.new(project_params)
        @project.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      #end

      redirect_to params['referer_url']

    else

      project_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @project = Project.new(project_params)
      @project.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = get_member(@project)
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = get_member(@project)
    project_params['member_profile_id'] = params[:author_members]
    @project.update_attributes(project_params)
    @project.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @project.destroy
    respond_to do |format|
      format.html { redirect_to(admin_projects_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
      end
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="projects_format.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_project(row,mp)
        end
      end
      redirect_to admin_projects_url
    else
      redirect_to admin_projects_url(:error => "1")
    end
  end

  def toggle_hide
    if params[:ids]
      @projects = Project.any_in(_id: params[:ids])

      @projects.each do |project|
        project.is_hidden = params[:disable]
        project.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @intro = ProjectIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? ProjectIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = ProjectIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? ProjectIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/Project')
  end

  def get_settings
    @project_types = ProjectType.all
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Project'}.first
  end

  private

  def set_project
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @project = Project.find_by(:uid => uid) rescue Project.find(params[:id])
  end

  def project_params
    params.require(:project).permit! rescue nil
  end

  def intro_params
    params.require(:project_intro).permit! rescue nil
  end
end